@@ -539,7 +539,9 @@ class Export:
             df_single_img_annots = yolo_dataset.loc[
                 yolo_dataset.img_filename == img_filename
             ]
-            annot_txt_file = img_filename.split(".")[0] + ".txt"
+            
+            basename, _ = os.path.splitext(img_filename)
+            annot_txt_file = basename + ".txt"
             # Use the value of the split collumn to create a directory
             # The values should be train, val, test or ''
             if use_splits:
@@ -678,29 +680,30 @@ class Export:
                 }
             ]
 
-            annotations = [
-                {
-                    "image_id": df["img_id"][i],
-                    "id": df.index[i],
-                    "segmented": df["ann_segmented"][i],
-                    "bbox": [
-                        df["ann_bbox_xmin"][i],
-                        df["ann_bbox_ymin"][i],
-                        df["ann_bbox_width"][i],
-                        df["ann_bbox_height"][i],
-                    ],
-                    "area": df["ann_area"][i],
-                    "segmentation": df["ann_segmentation"][i],
-                    "iscrowd": df["ann_iscrowd"][i],
-                    "pose": df["ann_pose"][i],
-                    "truncated": df["ann_truncated"][i],
-                    "category_id": df["cat_id"][i],
-                    "difficult": df["ann_difficult"][i],
-                }
-            ]
-
             # Skip this if cat_id is na
             if not pd.isna(df["cat_id"][i]):
+
+                annotations = [
+                    {
+                        "image_id": df["img_id"][i],
+                        "id": df.index[i],
+                        "segmented": df["ann_segmented"][i],
+                        "bbox": [
+                            df["ann_bbox_xmin"][i],
+                            df["ann_bbox_ymin"][i],
+                            df["ann_bbox_width"][i],
+                            df["ann_bbox_height"][i],
+                        ],
+                        "area": df["ann_area"][i],
+                        "segmentation": df["ann_segmentation"][i],
+                        "iscrowd": df["ann_iscrowd"][i],
+                        "pose": df["ann_pose"][i],
+                        "truncated": df["ann_truncated"][i],
+                        "category_id": int(df["cat_id"][i]),
+                        "difficult": df["ann_difficult"][i],
+                    }
+                ]
+
                 categories = [
                     {
                         "id": int(df["cat_id"][i]),
